==> qtjambi-datavisualization-6.6.1-sources.jar: io/qt/datavis/QBarDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QBarDataArray</a></code></p>
 */
public class QBarDataArray extends io.qt.core.QList<io.qt.datavis.@Nullable QBarDataRow>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QBarDataArray::<wbr/>QBarDataArray()</code></p>
     */
    public QBarDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBarDataArray instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBarDataArray(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QBarDataArray)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QBarDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QBarDataArray clone_native(long __this_nativeId);
}

==> qtjambi-datavisualization-6.6.3-sources.jar: io/qt/datavis/QBarDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QBarDataArray</a></code></p>
 */
public class QBarDataArray extends io.qt.core.QList<io.qt.datavis.@Nullable QBarDataRow>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QBarDataArray::<wbr/>QBarDataArray()</code></p>
     */
    public QBarDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBarDataArray instance);
    
    /**
     * <p>See <code>QBarDataArray::<wbr/>QBarDataArray(QBarDataArray)</code></p>
     */
    public QBarDataArray(io.qt.datavis.@NonNull QBarDataArray other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QBarDataArray instance, io.qt.datavis.QBarDataArray other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBarDataArray(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QBarDataArray::<wbr/>QBarDataArray(QBarDataArray)</code></p>
     */
    @QtUninvokable
    @Override
    public QBarDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QBarDataArray clone_native(long __this_nativeId);
}
